import{aR as r,aS as n,a5 as o,aT as c,aU as d,aV as p,aW as f,aX as m,aY as u,aZ as s,a_ as g,a$ as b,b0 as l}from"./jwt-decode.esm-CQm3LY6y.js";import{g as y,r as i}from"./router-DUOjFG4C.js";import{s as w}from"./workspaceStore-BnjNoni6.js";import{_}from"./App.vue_vue_type_style_index_0_lang-CKMK8HB1.js";import"./userStore-CEwj0HpY.js";import"./url-DLnEW9pi.js";import"./colorHelpers-DpdYunNI.js";import"./PlayerConfigProvider-Qduvuc1g.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="2c729130-5f2b-4009-9c4f-97d55388eb6c",t._sentryDebugIdIdentifier="sentry-dbid-2c729130-5f2b-4009-9c4f-97d55388eb6c")}catch{}})();class h{static init(){setInterval(()=>{fetch("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await y(),a=r(),e=n({render:()=>o(_)});c.init(),d(e,i,t),h.init(),e.use(i),e.use(a),e.use(p),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",m),e.component("Message",u),s(e,g),s(e,b),s(e,l)})();
//# sourceMappingURL=player-BfjtRzc4.js.map
