import{l as s,n as i,_ as d}from"./jwt-decode.esm-CQm3LY6y.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="5724dce4-2ffb-4d31-a773-b81a7ceaa4e7",e._sentryDebugIdIdentifier="sentry-dbid-5724dce4-2ffb-4d31-a773-b81a7ceaa4e7")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:a,RangePicker:o}=s(i),g=d(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(a.name,a),e)});export{g as D,r as M,a as Q,o as R,t as W};
//# sourceMappingURL=dayjs-fO5_K0JK.js.map
