import{a as f,ad as _,ac as p,ae as n,p as m,e as c,w as i,b as g,M as y,W as v,j as w,u as r,h as k,U as I}from"./jwt-decode.esm-CQm3LY6y.js";import{A as T,T as h}from"./index-C8KaSCto.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="7987839f-c65c-4ea8-8066-fac5377fcdfb",e._sentryDebugIdIdentifier="sentry-dbid-7987839f-c65c-4ea8-8066-fac5377fcdfb")}catch{}})();const x=f({__name:"TablesTabs",setup(e){const a=_(),t=p(),u=String(t.name),d=t.params.projectId,l=[{label:n.translate("i18n_tablestabs_tables_list"),value:"tables"},{label:n.translate("i18n_tablestabs_diagram_view"),value:"tables-diagram"},{label:n.translate("i18n_tablestabs_run_sql"),value:"sql"}],b=o=>{a.push({name:String(o),params:{projectId:d}})};return(o,D)=>(c(),m(r(h),{"active-key":r(u),options:l,"onUpdate:activeKey":b},{default:i(()=>[(c(),g(y,null,v(l,s=>w(r(T),{key:s.value,name:s.value},{tab:i(()=>[k("span",null,I(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{x as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang-B2YJENMa.js.map
