import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-CFrOZlEV.js";import{a as u,b as i,j as d,u as n,ad as f,ac as l,e as m,aN as b}from"./jwt-decode.esm-CQm3LY6y.js";import{u as _}from"./workspaceStore-BnjNoni6.js";import"./CircularLoading-DJqJpzzK.js";import"./Logo-BgkfgO9Z.js";import"./string-W5Qb0ZHU.js";import"./index-B7v0_G2C.js";import"./userStore-CEwj0HpY.js";import"./url-DLnEW9pi.js";import"./colorHelpers-DpdYunNI.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="9bafeb24-123b-4a03-89c8-be569f23b0f2",e._sentryDebugIdIdentifier="sentry-dbid-9bafeb24-123b-4a03-89c8-be569f23b0f2")}catch{}})();const g={class:"runner"},y=u({__name:"Login",setup(e){const o=f(),a=l(),r=_(),c=async()=>{const{redirect:t,...s}=a.query;if(t){await o.push({path:t,query:s,params:a.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>(m(),i("div",g,[d(p,{"logo-url":n(r).state.workspace?.logoUrl??void 0,"brand-name":n(r).state.workspace?.brandName,locale:n(r).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),E=b(y,[["__scopeId","data-v-12c690e1"]]);export{E as default};
//# sourceMappingURL=Login-Dg0SAvNu.js.map
