import{O as s}from"./OmniChat-CuNNSySh.js";import{u as c}from"./omniChatStore-2WRSxoBF.js";import{a,ac as i,p as f,g as u,u as t,e as d}from"./jwt-decode.esm-CQm3LY6y.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="f63ce971-0ffc-4664-9270-452d931c05fa",e._sentryDebugIdIdentifier="sentry-dbid-f63ce971-0ffc-4664-9270-452d931c05fa")}catch{}})();const g=a({__name:"ConsoleOmniChat",setup(e){const n=i().params.projectId,o=c();return o.init("console",n),(l,p)=>t(o).controller&&t(o).repository?(d(),f(s,{key:0,"ai-chat-repository":t(o).repository,controller:t(o).controller,environment:{origin:"console",projectId:t(n)},"show-console-suggestions":!0},null,8,["ai-chat-repository","controller","environment"])):u("",!0)}});export{g as _};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang-DFVHlumR.js.map
