import{a,b as s,e as o,j as d,u as r,b6 as c,aN as f}from"./jwt-decode.esm-CQm3LY6y.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="f2babd47-f3df-458e-9127-ec7bb0657073",e._sentryDebugIdIdentifier="sentry-dbid-f2babd47-f3df-458e-9127-ec7bb0657073")}catch{}})();const i={class:"centered"},_=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",i,[d(r(c))]))}}),p=f(_,[["__scopeId","data-v-52e6209a"]]);export{p as L};
//# sourceMappingURL=LoadingContainer-sWI2CMQh.js.map
