import{O as l}from"./workspaceStore-BnjNoni6.js";import{a as c,D as u,b,j as o,w as n,u as a,aj as _,ak as f,S as r,U as s,ae as d,e as p}from"./jwt-decode.esm-CQm3LY6y.js";import"./userStore-CEwj0HpY.js";import"./url-DLnEW9pi.js";import"./colorHelpers-DpdYunNI.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b550b7b5-8c5c-404b-b691-412eded9bd04",e._sentryDebugIdIdentifier="sentry-dbid-b550b7b5-8c5c-404b-b691-412eded9bd04")}catch{}})();const D=c({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new l().logoutCallback()}),(t,i)=>(p(),b("div",null,[o(a(_),null,{default:n(()=>[r(s(a(d).translate("i18n_oidclogoutcallback_authenticated_title")),1)]),_:1}),o(a(f),null,{default:n(()=>[r(s(a(d).translate("i18n_oidclogoutcallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLogoutCallback-BbHK3VRs.js.map
