import{_ as m}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-BEO27EMA.js";import{B as y}from"./BaseLayout-Kttv-SRZ.js";import{a as l,P as _,a1 as v,aN as u,aG as b,aH as g,e as f,b as h,h as o,K as s,D as w,ad as S,p as k,w as n,ac as B,j as i,u as I}from"./jwt-decode.esm-CQm3LY6y.js";import{u as $}from"./editor-B7X1y5uJ.js";import{A as D}from"./index-BaY8SZ_8.js";import"./Logo-BgkfgO9Z.js";import"./router-DUOjFG4C.js";import"./workspaceStore-BnjNoni6.js";import"./userStore-CEwj0HpY.js";import"./url-DLnEW9pi.js";import"./colorHelpers-DpdYunNI.js";import"./useCodebaseEvents-cPfYwxe_.js";import"./contracts.generated-ChorS9LP.js";import"./ts.worker-BIIJMa7D.js";import"./constants-BkB36yfF.js";import"./linters-Dc14ePYJ.js";import"./asyncComputed-_0zTJceu.js";import"./index-Bt656mEJ.js";import"./index-BtK_X6EO.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="c706a04a-05f1-4865-88cc-d9cd0c1bd5d2",e._sentryDebugIdIdentifier="sentry-dbid-c706a04a-05f1-4865-88cc-d9cd0c1bd5d2")}catch{}})();const L=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...v(r)}}}),P={class:"v-spinner"};function x(e,r,a,d,c,p){return b((f(),h("div",P,[o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const K=u(L,[["render",x],["__scopeId","data-v-06538001"]]),R={class:"content"},j=l({__name:"ProjectLogin",setup(e){const r=B(),a=S(),d=$();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function p(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=p();if(!t){a.push({name:"error"});return}await d.createLogin(t).then(c),a.push({name:"editor"})}),(t,z)=>(f(),k(y,null,{navbar:n(()=>[i(I(D),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:n(()=>[i(m)]),_:1})]),content:n(()=>[o("div",R,[i(K)])]),_:1}))}}),ee=u(j,[["__scopeId","data-v-d2a19803"]]);export{ee as default};
//# sourceMappingURL=ProjectLogin-D1vwNXG5.js.map
