import{C as p,_ as n}from"./View.vue_vue_type_script_setup_true_lang-_5nuNSi6.js";import{a as i,ac as s,p as m,e as a,u as c}from"./jwt-decode.esm-CQm3LY6y.js";import"./router-iclNQ3sb.js";import"./ts.worker-BIIJMa7D.js";import"./fetch-D_GCFhB2.js";import"./record-Dzon-Vi8.js";import"./SaveButton-DqdZ39XW.js";import"./ExclamationCircleOutlined-DEXumhaP.js";import"./CrudView-BCKz8q7-.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-yaUz4fth.js";import"./constants-BkB36yfF.js";import"./url-DLnEW9pi.js";import"./PhDotsThreeVertical.vue-D4TsgP8r.js";import"./index-Bt656mEJ.js";import"./asyncComputed-_0zTJceu.js";import"./omniChatStore-2WRSxoBF.js";import"./uuid-DEeQP7e4.js";import"./PhCopySimple.vue-B6w30IRp.js";import"./PhPencil.vue-DbapJaiy.js";import"./useCodebaseEvents-cPfYwxe_.js";import"./contracts.generated-ChorS9LP.js";import"./index-B7v0_G2C.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="11d2189f-158c-42ba-8101-cb44b0216899",o._sentryDebugIdIdentifier="sentry-dbid-11d2189f-158c-42ba-8101-cb44b0216899")}catch{}})();const A=i({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new p(t);return(d,f)=>(a(),m(n,{"env-var-repository":c(e),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars-CU69XEkg.js.map
