import{a as l,c as o,b as s,g as r,E as d,U as f,bb as g,e as t,aN as u}from"./jwt-decode.esm-CQm3LY6y.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="fafb4479-1fdb-4181-a370-4c3a680ecb23",e._sentryDebugIdIdentifier="sentry-dbid-fafb4479-1fdb-4181-a370-4c3a680ecb23")}catch{}})();const b={class:"logo"},m=["src","alt"],y=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){g(i=>({v4521d904:n.value}));const a=e,n=o(()=>a.size==="small"?"24px":a.size==="large"?"80px":"50px"),c=o(()=>`${a.brandName} Logo`);return(i,p)=>(t(),s("div",b,[e.imageUrl?(t(),s("img",{key:0,class:"logo-img",src:e.imageUrl,alt:c.value},null,8,m)):r("",!0),e.hideText?r("",!0):(t(),s("span",{key:1,class:d(e.size)},f(e.brandName),3))]))}}),_=u(y,[["__scopeId","data-v-8f34aac0"]]);export{_ as L};
//# sourceMappingURL=Logo-BgkfgO9Z.js.map
