import{_ as k}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-BEO27EMA.js";import{A as h}from"./constants-BkB36yfF.js";import{a as v,c as y,ac as A,ae as o,b as B,j as d,p as f,g as m,w as t,u as e,aj as I,b1 as p,B as N,S as a,U as u,h as x,b2 as C,ad as S,e as c,aN as T}from"./jwt-decode.esm-CQm3LY6y.js";import{u as D}from"./workspaceStore-BnjNoni6.js";import{C as E}from"./index-C8KaSCto.js";import"./Logo-BgkfgO9Z.js";import"./userStore-CEwj0HpY.js";import"./url-DLnEW9pi.js";import"./colorHelpers-DpdYunNI.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new H().stack;i&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[i]="9b940476-d0c7-4640-91af-231d3654918a",r._sentryDebugIdIdentifier="sentry-dbid-9b940476-d0c7-4640-91af-231d3654918a")}catch{}})();const R={class:"inner-content"},V={class:"card-content"},j=v({__name:"Error",setup(r){const i=A(),g=S(),_=D(),w=y(()=>_.state.workspace?.name??_.state.workspace?.brandName),n=y(()=>{const{status:l}=i.params;switch(l){case"404":return{status:l,title:o.translate("i18n_page_not_found"),message:o.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:l,title:o.translate("i18n_access_denied"),message:o.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:o.translate("i18n_internal_error"),message:o.translate("i18n_internal_error_message"),showAd:!1}}}),b=()=>{g.push({name:"playerHome"})};return(l,s)=>(c(),B("div",R,[d(e(I),null,{default:t(()=>[a(u(n.value.title),1)]),_:1}),d(e(p),{class:"message"},{default:t(()=>[a(u(n.value.message),1)]),_:1}),n.value.action?(c(),f(e(N),{key:0,type:"link",onClick:b},{default:t(()=>[a(u(n.value.action),1)]),_:1})):m("",!0),n.value.showAd?(c(),f(e(E),{key:1,bordered:!1,class:"card"},{default:t(()=>[x("div",V,[d(k,{style:{"margin-bottom":"10px"}}),d(e(p),null,{default:t(()=>[a("This page is part of "+u(w.value?`the ${w.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(_).state.workspace?(c(),f(e(p),{key:0},{default:t(()=>[s[1]||(s[1]=a("Automate your own processes by getting started ",-1)),d(e(C),{href:e(h).HOMEPAGE},{default:t(()=>[...s[0]||(s[0]=[a("here",-1)])]),_:1},8,["href"]),s[2]||(s[2]=a(".",-1))]),_:1})):m("",!0)])]),_:1})):m("",!0)]))}}),H=T(j,[["__scopeId","data-v-522ad0d4"]]);export{H as default};
//# sourceMappingURL=Error-CjMtNJHi.js.map
