import{P as g}from"./PlayerNavbar-CeRzRrJT.js";import{a as _,ac as c,r as h,c as b,b as y,p as k,g as v,h as w,u as n,j as L,a4 as C,ad as N,e as i,aN as I}from"./jwt-decode.esm-CQm3LY6y.js";import{u as V}from"./workspaceStore-BnjNoni6.js";import"./userStore-CEwj0HpY.js";import"./metadata-CVmtnoyX.js";import"./PhWebhooksLogo.vue-BPJIK1pC.js";import"./LoadingOutlined-DpOEkefJ.js";import"./PhSignOut.vue-B-W1FD5i.js";import"./index-BtK_X6EO.js";import"./url-DLnEW9pi.js";import"./colorHelpers-DpdYunNI.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="50b83771-cd2e-4145-9e5a-de05d2b845f5",o._sentryDebugIdIdentifier="sentry-dbid-50b83771-cd2e-4145-9e5a-de05d2b845f5")}catch{}})();const B={class:"main-container"},D={class:"content"},R=_({__name:"Main",setup(o){const e=N(),t=V(),d=c().path,a=h(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},m=b(()=>!!c().meta.hideLogin);return(r,s)=>{const f=C("RouterView");return i(),y("div",B,[n(t).state.workspace?(i(),k(g,{key:0,"current-path":n(d),"hide-login":m.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):v("",!0),w("section",D,[L(f)])])}}}),F=I(R,[["__scopeId","data-v-f095bece"]]);export{F as default};
//# sourceMappingURL=Main-Dut1ac5k.js.map
