import{a as i,c as n,b as d,e as c,E as o,K as a,h as u,f}from"./jwt-decode.esm-CQm3LY6y.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f98acca9-662d-49cb-8f51-13880755b566",e._sentryDebugIdIdentifier="sentry-dbid-f98acca9-662d-49cb-8f51-13880755b566")}catch{}})();const p=i({__name:"ScrollArea",props:{innerClass:{},outerClass:{},outerStyle:{},innerStyle:{}},setup(e){const t=e,s=n(()=>t.outerStyle?{position:"relative",...t.outerStyle}:{position:"relative"}),r=n(()=>({position:"absolute",inset:0,overflow:"auto",...t.innerStyle??{}}));return(l,y)=>(c(),d("div",{style:a(s.value),class:o(e.outerClass)},[u("div",{style:a(r.value),class:o(e.innerClass)},[f(l.$slots,"default")],6)],6))}});export{p as _};
//# sourceMappingURL=ScrollArea.vue_vue_type_script_setup_true_lang-CvaYUw-I.js.map
