const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-7SJnOURw.js","assets/workspaceStore-BnjNoni6.js","assets/jwt-decode.esm-CQm3LY6y.js","assets/jwt-decode-UwARlUKu.css","assets/userStore-CEwj0HpY.js","assets/url-DLnEW9pi.js","assets/colorHelpers-DpdYunNI.js","assets/OidcLogoutCallback-BbHK3VRs.js","assets/Login-Dg0SAvNu.js","assets/Login.vue_vue_type_script_setup_true_lang-CFrOZlEV.js","assets/CircularLoading-DJqJpzzK.js","assets/CircularLoading-C7OKHy4X.css","assets/Logo-BgkfgO9Z.js","assets/Logo-D2kepPyK.css","assets/string-W5Qb0ZHU.js","assets/index-B7v0_G2C.js","assets/Login-cMuNqCbG.css","assets/Login-C1k-SC0u.css","assets/Main-Dut1ac5k.js","assets/PlayerNavbar-CeRzRrJT.js","assets/metadata-CVmtnoyX.js","assets/PhWebhooksLogo.vue-BPJIK1pC.js","assets/LoadingOutlined-DpOEkefJ.js","assets/PhSignOut.vue-B-W1FD5i.js","assets/index-BtK_X6EO.js","assets/PlayerNavbar-VlEtzX8f.css","assets/Main-DqPmGmnC.css","assets/Home-DYvOEzCA.js","assets/Watermark-B3gfKlik.js","assets/constants-BkB36yfF.js","assets/Watermark-DMbnzHiR.css","assets/PhArrowSquareOut.vue-vLeyI9UL.js","assets/index-C8KaSCto.js","assets/Home-B6UGln4L.css","assets/Error-CjMtNJHi.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-BEO27EMA.js","assets/Error-CIbhyrKS.css","assets/Form-CReSUOWC.js","assets/FormRunner-djVhkgGz.js","assets/Steps-CCzu7Q5O.js","assets/index-BXlweqZj.js","assets/Steps-DqO_G9S3.css","assets/FormRunner-61-wByB6.css","assets/redirect-DEHFkoSn.js","assets/asyncComputed-_0zTJceu.js","assets/uuid-DEeQP7e4.js","assets/Form-BkLIfVj9.css"])))=>i.map(i=>d[i]);
import{af as c,ag as d,ah as t,ai as b}from"./jwt-decode.esm-CQm3LY6y.js";import{a as m}from"./workspaceStore-BnjNoni6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="3a85cb78-5f16-4b37-997b-9ac2ce387459",e._sentryDebugIdIdentifier="sentry-dbid-3a85cb78-5f16-4b37-997b-9ac2ce387459")}catch{}})();const f=async()=>{try{const e=await fetch("/_editor/api/workspace/version");return e.ok&&(await e.json()).version||"bbf98ac9d19bb14eb35b100fb5609398d921298b"}catch(e){return console.error("Failed to fetch Abstra version:",e),"bbf98ac9d19bb14eb35b100fb5609398d921298b"}},u=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-7SJnOURw.js"),__vite__mapDeps([0,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-BbHK3VRs.js"),__vite__mapDeps([7,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-Dg0SAvNu.js"),__vite__mapDeps([8,9,2,3,1,4,5,6,10,11,12,13,14,15,16,17])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-Dut1ac5k.js"),__vite__mapDeps([18,19,4,2,3,1,5,6,20,21,22,23,24,25,26])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-DYvOEzCA.js"),__vite__mapDeps([27,20,2,3,21,28,1,4,5,6,29,30,31,32,22,33])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-CjMtNJHi.js"),__vite__mapDeps([34,35,12,2,3,13,29,1,4,5,6,32,36])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-CReSUOWC.js"),__vite__mapDeps([37,4,2,3,38,9,1,5,6,10,11,12,13,14,15,16,39,40,41,28,29,30,42,43,44,45,46])),meta:{hideLogin:!0}}]}],o=c({history:d("/"),routes:u,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),p=e=>async(a,r)=>{if(b(a,r),a.meta.allowUnauthenticated)return;const n=await m(a.path),{redirect:i,...s}=a.query;switch(n.status){case"ALLOWED":break;case"UNAUTHORIZED":await e.push({name:"playerLogin",query:{...s,redirect:i||a.path},params:a.params});break;case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};o.beforeEach(p(o));export{u as a,p as b,f as g,o as r};
//# sourceMappingURL=router-DUOjFG4C.js.map
