import{a as o,b as d,e as s,E as n,h as l,f as r,aN as i}from"./jwt-decode.esm-CQm3LY6y.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="86abde25-9325-4e42-9e6e-5315b4e986ca",e._sentryDebugIdIdentifier="sentry-dbid-86abde25-9325-4e42-9e6e-5315b4e986ca")}catch{}})();const c=o({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean}},setup(e){return(t,a)=>(s(),d("div",{class:n(["content-layout",{"no-padding":e.noPadding}])},[l("div",{class:n(["centered-layout",{"full-width":e.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)],2))}}),u=i(c,[["__scopeId","data-v-fb4d67f9"]]);export{u as C};
//# sourceMappingURL=ContentLayout-BIXBdIN2.js.map
