import{j as o,I as u,C as f}from"./jwt-decode.esm-CQm3LY6y.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="0cf124e1-6ec7-4418-8334-c2e685122705",e._sentryDebugIdIdentifier="sentry-dbid-0cf124e1-6ec7-4418-8334-c2e685122705")}catch{}})();function l(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(i){return Object.getOwnPropertyDescriptor(r,i).enumerable}))),n.forEach(function(i){a(e,i,r[i])})}return e}function a(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var c=function(t,r){var n=l({},t,r.attrs);return o(u,l({},n,{icon:f}),null)};c.displayName="CloseCircleOutlined";c.inheritAttrs=!1;export{c as C};
//# sourceMappingURL=CloseCircleOutlined-CCkteZ-j.js.map
