.connector-card[data-v-86187920]{cursor:pointer;transition:all .3s}.connector-card[data-v-86187920]:hover{box-shadow:0 0 15px #0000001a}.connector-card.unavailable[data-v-86187920]{opacity:.7}.connector-card.unavailable[data-v-86187920]:hover{box-shadow:none}.connectors-grid[data-v-21b5de4f]{display:grid;grid-template-columns:repeat(auto-fill,minmax(300px,1fr));gap:20px}
