import"./jwt-decode.esm-CQm3LY6y.js";(function(){try{var d=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(d._sentryDebugIds=d._sentryDebugIds||{},d._sentryDebugIds[e]="3d57653d-09b4-426d-b382-4d390ba4f6c5",d._sentryDebugIdIdentifier="sentry-dbid-3d57653d-09b4-426d-b382-4d390ba4f6c5")}catch{}})();const o=(...d)=>window.fetch(...d);export{o as l};
//# sourceMappingURL=fetch-D_GCFhB2.js.map
