import{_ as d}from"./App.vue_vue_type_style_index_0_lang-CKMK8HB1.js";import"./userStore-CEwj0HpY.js";import"./jwt-decode.esm-CQm3LY6y.js";import"./PlayerConfigProvider-Qduvuc1g.js";import"./colorHelpers-DpdYunNI.js";import"./workspaceStore-BnjNoni6.js";import"./url-DLnEW9pi.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="355b28da-a765-425b-9c42-f69efe6b3cfb",e._sentryDebugIdIdentifier="sentry-dbid-355b28da-a765-425b-9c42-f69efe6b3cfb")}catch{}})();export{d as default};
//# sourceMappingURL=App-DwN_KhI9.js.map
