import{j as c,I as l,ab as o}from"./jwt-decode.esm-CQm3LY6y.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="12e70c6f-3f50-4e7f-a7c7-e21ffe8b5d5a",e._sentryDebugIdIdentifier="sentry-dbid-12e70c6f-3f50-4e7f-a7c7-e21ffe8b5d5a")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){u(e,a,n[a])})}return e}function u(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var f=function(t,n){var r=i({},t,n.attrs);return c(l,i({},r,{icon:o}),null)};f.displayName="ExclamationCircleOutlined";f.inheritAttrs=!1;export{f as E};
//# sourceMappingURL=ExclamationCircleOutlined-DEXumhaP.js.map
