import{C as r}from"./router-iclNQ3sb.js";import"./jwt-decode.esm-CQm3LY6y.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="0cf8401d-4df6-46e8-a994-8bd8c89bbfd4",a._sentryDebugIdIdentifier="sentry-dbid-0cf8401d-4df6-46e8-a994-8bd8c89bbfd4")}catch{}})();class s{async list(e){return r.get(`organizations/${e}/folders`)}async create(e){return r.post(`organizations/${e.organizationId}/folders`,{name:e.name,memberIds:e.memberIds})}async checkNameAvailability(e,n){return r.post(`organizations/${e}/folders/name-available`,{folderName:n})}async delete(e,n){return r.delete(`organizations/${e}/folders/${n}`)}async update(e,n){return r.patch(`organizations/${e}/folders/${n.id}/`,{name:n.name,memberIds:n.memberIds})}}export{s as F};
//# sourceMappingURL=folder-C6VWEE04.js.map
