import{C as a}from"./router-iclNQ3sb.js";import"./jwt-decode.esm-CQm3LY6y.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[t]="6a08bcd9-8aef-4929-b624-50b189fff9bf",s._sentryDebugIdIdentifier="sentry-dbid-6a08bcd9-8aef-4929-b624-50b189fff9bf")}catch{}})();class i{urlPath="api-keys";async create({projectId:t,name:e}){return a.post(`projects/${t}/${this.urlPath}`,{name:e})}async delete(t,e){await a.delete(`projects/${t}/${this.urlPath}/${e}`)}async list(t){return a.get(`projects/${t}/${this.urlPath}`)}}const r=new i;class n{constructor(t){this.dto=t}static async list(t){return(await r.list(t)).map(d=>new n(d))}static async create(t){const e=await r.create(t);return new n(e)}static async delete(t,e){await r.delete(t,e)}get id(){return this.dto.id}get name(){return this.dto.name}get createdAt(){return new Date(this.dto.createdAt)}get ownerId(){return this.dto.createdBy}get value(){return this.dto.value??null}}export{n as A};
//# sourceMappingURL=apiKey-BmtHyRhp.js.map
