import{A as n}from"./index-BXlweqZj.js";import{a,c as o,b as r,g as d,E as f,j as c,u as l,e as p,aN as i}from"./jwt-decode.esm-CQm3LY6y.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="fdbbe2d2-7060-480a-ad4a-e38e942f8d03",e._sentryDebugIdIdentifier="sentry-dbid-fdbbe2d2-7060-480a-ad4a-e38e942f8d03")}catch{}})();const u=a({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,t=o(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(m,b)=>e.stepsInfo?(p(),r("nav",{key:0,class:f(["p-steps",{"full-screen":!e.isPreview}])},[c(l(n),{current:e.stepsInfo.current-1,items:t.value,responsive:!1},null,8,["current","items"])],2)):d("",!0)}}),_=i(u,[["__scopeId","data-v-58fdd395"]]);export{_ as S};
//# sourceMappingURL=Steps-CCzu7Q5O.js.map
