.cli[data-v-ee1d10cd]{background-color:#555;border-radius:5px;padding:10px;color:#fff;font-family:monospace;overflow-x:hidden;word-break:break-all;white-space:pre-wrap;max-width:100%}[data-v-f7630ec7]:root{--abstra-main-color-dark: #343b46}.tree[data-v-f7630ec7] .ant-tree-node-content-wrapper{-webkit-user-select:auto;user-select:auto}.ask-to-ai[data-v-f7630ec7]{display:flex;gap:6px;align-items:center;cursor:pointer;color:#d14056}.ask-to-ai.disabled[data-v-f7630ec7]{cursor:not-allowed;opacity:.5}
